==> yybbs-0.54.zip: yybbs/language/japanese/main.php <==
<?
	define ( "_MD_YYBBS_BBSLIST", "££Ӱ" );
	define ( "_MD_YYBBS_BBSTITLE", "££̾" );
	define ( "_MD_YYBBS_BBSEX", "" );

	define ( "_MD_YYBBS_POSTER", "Ƽ" );
	define ( "_MD_YYBBS_POSTDATE", "" );
	define ( "_MD_YYBBS_RES", "ֿ" );

	define ( "_MD_YYBBS_GO_TOP", "ȥåפ" );
	define ( "_MD_YYBBS_BBS_TOP", "££ӥȥå" );
	define ( "_MD_YYBBS_HOWTO", "αջ" );
	define ( "_MD_YYBBS_SEARCH", "ɸ" );
	define ( "_MD_YYBBS_REVICE", "" );
	define ( "_MD_YYBBS_DELETE", "" );
	define ( "_MD_YYBBS_SEND", "" );
	define ( "_MD_YYBBS_SIG", "Υץ KENT  yybbs  xoops(PHP) ˰ܿΤǤ" );
	define ( "_MD_YYBBS_SIG_LINK", "- <a href='http://www.kent-web.com/' target='_top'>KENT</a> -" );

	define ( "_MD_YYBBS_GO_BBS", "ǼĤ" );
	define ( "_MD_YYBBS_GO_BACK", "̤" );

	// res
	define ( "_MD_YYBBS_RESPONCE_HEADMES", "ʲϵNO. <B>%u</B> ˴ؤ<a href='#REF'>ֿե</a>Ǥ" );

	// revice
	define ( "_MD_YYBBS_REVICE_HEADMES", "ѹʬΤ߽ܥ򲡤Ʋ" );

	// forms
	define ( "_MD_YYBBS_NAME", "̾" );
	define ( "_MD_YYBBS_EMAIL", "ť᡼" );
	define ( "_MD_YYBBS_TITLE", "ȥ" );
	define ( "_MD_YYBBS_SUBMIT", "Ƥ" );
	define ( "_MD_YYBBS_RESET", "ꥻå" );
	define ( "_MD_YYBBS_MESSAGE", "å" );
	define ( "_MD_YYBBS_URL", "" );
	define ( "_MD_YYBBS_IMAGE", "᡼" );
	define ( "_MD_YYBBS_IMAGE_REF", "᡼" );
	define ( "_MD_YYBBS_PASSWD", "ѥ" );
	define ( "_MD_YYBBS_PASSWD_EX", "(ѿ8ʸ)" );
	define ( "_MD_YYBBS_COLOR", "ʸ" );
	define ( "_MD_YYBBS_COLORCHIP", "" );


	//ICON LIST
	define("_MD_YYBBS_LANG_ICONIMAGE","᡼");
	define("_MD_YYBBS_LANG_WINDOWCLOSE","ɥĤ");


	define ( "_MD_YYBBS_BBS_NO_SELECTED", "££Ӥ򤵤Ƥޤ" );
	define ( "_MD_YYBBS_BBS_UNDEFINED", "££Ӥޤ" );
	define ( "_MD_YYBBS_BBS_REQERR", "ʥꥯȤǤ" );

	define ( "_MD_YYBBS_ERRMES", "ERROR!" );
	define ( "_MD_YYBBS_ERRMES_NAME", "̾ϤƤ" );
	define ( "_MD_YYBBS_ERRMES_TITLE", "ȥϤƤ" );
	define ( "_MD_YYBBS_ERRMES_MESSAGE", "ƤϤƤ" );
	define ( "_MD_YYBBS_ERRMES_PASSWD", "No.ޤϰžڥϥ졢⤷ϴְäƤޤ" );
	define ( "_MD_YYBBS_ERRMES_POST", "ǡ١񤭹ߤǥ顼ޤ" );

	define ( "_MD_YYBBS_POST_SUCCESS", "Ƥ˽ޤ" );
	define ( "_MD_YYBBS_POST_FAIL", "Ƥ˽ޤ" );
	define ( "_MD_YYBBS_REVICE_TRUE", "λޤ" );
	define ( "_MD_YYBBS_DELETE_TRUE", "λޤ" );

?>

==> yybbs-0.55.zip: yybbs/language/japanese/main.php <==
<?php
/**
@version $Id$
*/
	define ( "_MD_YYBBS_BBSLIST", "££Ӱ" );
	define ( "_MD_YYBBS_BBSTITLE", "££̾" );
	define ( "_MD_YYBBS_BBSEX", "" );

	define ( "_MD_YYBBS_POSTER", "Ƽ" );
	define ( "_MD_YYBBS_POSTDATE", "" );
	define ( "_MD_YYBBS_RES", "ֿ" );

	define ( "_MD_YYBBS_GO_TOP", "ȥåפ" );
	define ( "_MD_YYBBS_BBS_TOP", "££ӥȥå" );
	define ( "_MD_YYBBS_HOWTO", "αջ" );
	define ( "_MD_YYBBS_SEARCH", "ɸ" );
	define ( "_MD_YYBBS_REVICE", "" );
	define ( "_MD_YYBBS_DELETE", "" );
	define ( "_MD_YYBBS_SEND", "" );
	define ( "_MD_YYBBS_SIG", "Υץ KENT  yybbs  xoops(PHP) ˰ܿΤǤ" );
	define ( "_MD_YYBBS_SIG_LINK", "- <a href='http://www.kent-web.com/' target='_top'>KENT</a> -" );

	define ( "_MD_YYBBS_GO_BBS", "ǼĤ" );
	define ( "_MD_YYBBS_GO_BACK", "̤" );

	// res
	define ( "_MD_YYBBS_RESPONCE_HEADMES", "ʲϵNO. <B>%u</B> ˴ؤ<a href='#REF'>ֿե</a>Ǥ" );

	// revice
	define ( "_MD_YYBBS_REVICE_HEADMES", "ѹʬΤ߽ܥ򲡤Ʋ" );

	// forms
	define ( "_MD_YYBBS_NAME", "̾" );
	define ( "_MD_YYBBS_EMAIL", "ť᡼" );
	define ( "_MD_YYBBS_TITLE", "ȥ" );
	define ( "_MD_YYBBS_SUBMIT", "Ƥ" );
	define ( "_MD_YYBBS_RESET", "ꥻå" );
	define ( "_MD_YYBBS_MESSAGE", "å" );
	define ( "_MD_YYBBS_URL", "" );
	define ( "_MD_YYBBS_IMAGE", "᡼" );
	define ( "_MD_YYBBS_IMAGE_REF", "᡼" );
	define ( "_MD_YYBBS_PASSWD", "ѥ" );
	define ( "_MD_YYBBS_PASSWD_EX", "(ѿ8ʸ)" );
	define ( "_MD_YYBBS_COLOR", "ʸ" );
	define ( "_MD_YYBBS_COLORCHIP", "" );


	//ICON LIST
	define("_MD_YYBBS_LANG_ICONIMAGE","᡼");
	define("_MD_YYBBS_LANG_WINDOWCLOSE","ɥĤ");


	define ( "_MD_YYBBS_BBS_NO_SELECTED", "££Ӥ򤵤Ƥޤ" );
	define ( "_MD_YYBBS_BBS_UNDEFINED", "££Ӥޤ" );
	define ( "_MD_YYBBS_BBS_REQERR", "ʥꥯȤǤ" );

	define ( "_MD_YYBBS_ERRMES", "ERROR!" );
	define ( "_MD_YYBBS_ERRMES_NAME", "̾ϤƤ" );
	define ( "_MD_YYBBS_ERRMES_TITLE", "ȥϤƤ" );
	define ( "_MD_YYBBS_ERRMES_MESSAGE", "ƤϤƤ" );
	define ( "_MD_YYBBS_ERRMES_PASSWD", "No.ޤϰžڥϥ졢⤷ϴְäƤޤ" );
	define ( "_MD_YYBBS_ERRMES_POST", "ǡ١񤭹ߤǥ顼ޤ" );

	define ( "_MD_YYBBS_POST_SUCCESS", "Ƥ˽ޤ" );
	define ( "_MD_YYBBS_POST_FAIL", "Ƥ˼Ԥޤ" );
	define ( "_MD_YYBBS_REVICE_TRUE", "λޤ" );
	define ( "_MD_YYBBS_DELETE_TRUE", "λޤ" );

	define ( "_MD_YYBBS_ERRMES_PERM", "ɬפʸ¤ͿƤޤ" );

	// howto
	define("_MD_YYBBS_LANG_HOWTO_TITLE","αջ");
	define("_MD_YYBBS_LANG_HOWTO_1","ηǼĤ<b>åб</b>Ǥ1ٵƤȡ̾ť᡼롢衢žڥξ2ܰʹߤϼưϤޤʤѼԤΥ֥饦åбξ");
	define("_MD_YYBBS_LANG_HOWTO_2","Ƥˤϡ<b>ϰڻѤǤޤ</b>");
	define("_MD_YYBBS_LANG_HOWTO_3","ƤǤɬϹܤ<b>֤̾</b><b>̾</b><b>֥å</b>Ǥť᡼롢衢žڥǤդǤ");
	define("_MD_YYBBS_LANG_HOWTO_4","ˤϡ<b>ȾѥʤϰڻѤʤǲ</b>ʸθȤʤޤ");
	define("_MD_YYBBS_LANG_HOWTO_5","ƻ<b>ְžڥ</b>ǤդΥѥɡʱѿ8ʸˤƤȡεϼ<b>žڥ</b>ˤäƽڤӺ뤳ȤǤޤ");
	define("_MD_YYBBS_LANG_HOWTO_6","ܥȤ˥󤷤ƽ񤭹ϡѥɤȤʤƤ⽤ǽǤ");
	define("_MD_YYBBS_LANG_HOWTO_7","¸ε<b>ֿ</b>򤹤뤳ȤǤޤƵξˤ<b>ֿ</b>ܥ򲡤ֿѥեबޤ");
	define("_MD_YYBBS_LANG_HOWTO_8","ԤפȽǤ뵭¾ͤ뵭ͽʤ뤳Ȥޤ");

?>
